Class: Google::Apis::ApigatewayV1beta::ApigatewayOperationMetadata
- Inherits:
-
Object
- Object
- Google::Apis::ApigatewayV1beta::ApigatewayOperationMetadata
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/apigateway_v1beta/classes.rb,
lib/google/apis/apigateway_v1beta/representations.rb,
lib/google/apis/apigateway_v1beta/representations.rb
Overview
Represents the metadata of the long-running operation.
Instance Attribute Summary collapse
-
#api_version ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#diagnostics ⇒ Array<Google::Apis::ApigatewayV1beta::ApigatewayOperationMetadataDiagnostic>
Output only.
-
#end_time ⇒ String
Output only.
-
#requested_cancellation ⇒ Boolean
(also: #requested_cancellation?)
Output only.
-
#status_message ⇒ String
Output only.
-
#target ⇒ String
Output only.
-
#verb ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ApigatewayOperationMetadata
constructor
A new instance of ApigatewayOperationMetadata.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ApigatewayOperationMetadata
Returns a new instance of ApigatewayOperationMetadata.
927 928 929 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 927 def initialize(**args) update!(**args) end |
Instance Attribute Details
#api_version ⇒ String
Output only. API version used to start the operation.
Corresponds to the JSON property apiVersion
885 886 887 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 885 def api_version @api_version end |
#create_time ⇒ String
Output only. The time the operation was created.
Corresponds to the JSON property createTime
890 891 892 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 890 def create_time @create_time end |
#diagnostics ⇒ Array<Google::Apis::ApigatewayV1beta::ApigatewayOperationMetadataDiagnostic>
Output only. Diagnostics generated during processing of configuration source
files.
Corresponds to the JSON property diagnostics
896 897 898 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 896 def diagnostics @diagnostics end |
#end_time ⇒ String
Output only. The time the operation finished running.
Corresponds to the JSON property endTime
901 902 903 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 901 def end_time @end_time end |
#requested_cancellation ⇒ Boolean Also known as: requested_cancellation?
Output only. Identifies whether the user has requested cancellation of the
operation. Operations that have successfully been cancelled have google.
longrunning.Operation.error value with a google.rpc.Status.code of 1,
corresponding to Code.CANCELLED.
Corresponds to the JSON property requestedCancellation
909 910 911 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 909 def requested_cancellation @requested_cancellation end |
#status_message ⇒ String
Output only. Human-readable status of the operation, if any.
Corresponds to the JSON property statusMessage
915 916 917 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 915 def @status_message end |
#target ⇒ String
Output only. Server-defined resource path for the target of the operation.
Corresponds to the JSON property target
920 921 922 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 920 def target @target end |
#verb ⇒ String
Output only. Name of the verb executed by the operation.
Corresponds to the JSON property verb
925 926 927 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 925 def verb @verb end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
932 933 934 935 936 937 938 939 940 941 |
# File 'lib/google/apis/apigateway_v1beta/classes.rb', line 932 def update!(**args) @api_version = args[:api_version] if args.key?(:api_version) @create_time = args[:create_time] if args.key?(:create_time) @diagnostics = args[:diagnostics] if args.key?(:diagnostics) @end_time = args[:end_time] if args.key?(:end_time) @requested_cancellation = args[:requested_cancellation] if args.key?(:requested_cancellation) @status_message = args[:status_message] if args.key?(:status_message) @target = args[:target] if args.key?(:target) @verb = args[:verb] if args.key?(:verb) end |