Class: Google::Apis::ApigatewayV1beta::ApigatewayService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ApigatewayV1beta::ApigatewayService
- Defined in:
- lib/google/apis/apigateway_v1beta/service.rb
Overview
API Gateway API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://apigateway.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Api in a given project and location.
-
#create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new ApiConfig in a given project and location.
-
#create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Gateway in a given project and location.
-
#delete_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Api.
-
#delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single ApiConfig.
-
#delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Gateway.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayLocation
Gets information about a location.
-
#get_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApi
Gets details of a single Api.
-
#get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApiConfig
Gets details of a single ApiConfig.
-
#get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayGateway
Gets details of a single Gateway.
-
#get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Gets the latest state of a long-running operation.
-
#initialize ⇒ ApigatewayService
constructor
A new instance of ApigatewayService.
-
#list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse
Lists ApiConfigs in a given project and location.
-
#list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse
Lists Apis in a given project and location.
-
#list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse
Lists Gateways in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Api.
-
#patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single ApiConfig.
-
#patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Gateway.
-
#set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#test_project_location_api_config_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_project_location_api_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_project_location_gateway_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ ApigatewayService
Returns a new instance of ApigatewayService.
47 48 49 50 51 52 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-apigateway_v1beta', client_version: Google::Apis::ApigatewayV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1080 1081 1082 1083 1084 1085 1086 1087 1088 1089 1090 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1080 def cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:cancel', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayCancelOperationRequest::Representation command.request_object = apigateway_cancel_operation_request_object command.response_representation = Google::Apis::ApigatewayV1beta::Empty::Representation command.response_class = Google::Apis::ApigatewayV1beta::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Api in a given project and location.
165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 165 def create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/apis', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApi::Representation command.request_object = apigateway_api_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['apiId'] = api_id unless api_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new ApiConfig in a given project and location.
467 468 469 470 471 472 473 474 475 476 477 478 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 467 def create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/configs', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig::Representation command.request_object = apigateway_api_config_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['apiConfigId'] = api_config_id unless api_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Gateway in a given project and location.
775 776 777 778 779 780 781 782 783 784 785 786 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 775 def create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/gateways', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayGateway::Representation command.request_object = apigateway_gateway_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['gatewayId'] = gateway_id unless gateway_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Api.
198 199 200 201 202 203 204 205 206 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 198 def delete_project_location_api(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single ApiConfig.
501 502 503 504 505 506 507 508 509 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 501 def delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Gateway.
808 809 810 811 812 813 814 815 816 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 808 def delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1115 1116 1117 1118 1119 1120 1121 1122 1123 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1115 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::Empty::Representation command.response_class = Google::Apis::ApigatewayV1beta::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayLocation
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayLocation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayLocation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApi
Gets details of a single Api.
228 229 230 231 232 233 234 235 236 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 228 def get_project_location_api(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayApi::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayApi command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApiConfig
Gets details of a single ApiConfig.
535 536 537 538 539 540 541 542 543 544 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 535 def get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
580 581 582 583 584 585 586 587 588 589 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 580 def get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
272 273 274 275 276 277 278 279 280 281 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 272 def get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayGateway
Gets details of a single Gateway.
838 839 840 841 842 843 844 845 846 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 838 def get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayGateway::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayGateway command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
882 883 884 885 886 887 888 889 890 891 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 882 def get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1146 1147 1148 1149 1150 1151 1152 1153 1154 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1146 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse
Lists ApiConfigs in a given project and location.
620 621 622 623 624 625 626 627 628 629 630 631 632 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 620 def list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/configs', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse
Lists Apis in a given project and location.
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 312 def list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/apis', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse
Lists Gateways in a given project and location.
921 922 923 924 925 926 927 928 929 930 931 932 933 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 921 def list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/gateways', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1191 1192 1193 1194 1195 1196 1197 1198 1199 1200 1201 1202 1203 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1191 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}/operations', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse
Lists information about the supported locations for this service. This method
lists locations based on the resource scope provided in the [
ListLocationsRequest.name] field: * Global locations: If name is empty,
the method lists the public locations available to all projects. * Project-
specific locations: If name follows the format projects/project`, the
method lists locations visible to that specific project. This includes public,
private, or other project-specific locations enabled for the project. For gRPC
and client library implementations, the resource name is passed as thename`
field. For direct service calls, the resource name is incorporated into the
request path based on the specific service implementation and version.
126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 126 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}/locations', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Api.
353 354 355 356 357 358 359 360 361 362 363 364 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 353 def patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApi::Representation command.request_object = apigateway_api_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single ApiConfig.
662 663 664 665 666 667 668 669 670 671 672 673 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 662 def patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig::Representation command.request_object = apigateway_api_config_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Gateway.
963 964 965 966 967 968 969 970 971 972 973 974 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 963 def patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayGateway::Representation command.request_object = apigateway_gateway_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
700 701 702 703 704 705 706 707 708 709 710 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 700 def set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 391 def set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
1001 1002 1003 1004 1005 1006 1007 1008 1009 1010 1011 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1001 def set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_api_config_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
739 740 741 742 743 744 745 746 747 748 749 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 739 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_api_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
430 431 432 433 434 435 436 437 438 439 440 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 430 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_gateway_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1040 1041 1042 1043 1044 1045 1046 1047 1048 1049 1050 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1040 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |