Class: Google::Apis::ApigatewayV1beta::ApigatewayService
- Inherits:
-
Core::BaseService
- Object
- Core::BaseService
- Google::Apis::ApigatewayV1beta::ApigatewayService
- Defined in:
- lib/google/apis/apigateway_v1beta/service.rb
Overview
API Gateway API
Constant Summary collapse
- DEFAULT_ENDPOINT_TEMPLATE =
"https://apigateway.$UNIVERSE_DOMAIN$/"
Instance Attribute Summary collapse
-
#key ⇒ String
API key.
-
#quota_user ⇒ String
Available to use for quota purposes for server-side applications.
Instance Method Summary collapse
-
#cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Starts asynchronous cancellation on a long-running operation.
-
#create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Api in a given project and location.
-
#create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new ApiConfig in a given project and location.
-
#create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Gateway in a given project and location.
-
#delete_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Api.
-
#delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single ApiConfig.
-
#delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Gateway.
-
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Deletes a long-running operation.
-
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayLocation
Gets information about a location.
-
#get_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApi
Gets details of a single Api.
-
#get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApiConfig
Gets details of a single ApiConfig.
-
#get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayGateway
Gets details of a single Gateway.
-
#get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource.
-
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Gets the latest state of a long-running operation.
-
#initialize ⇒ ApigatewayService
constructor
A new instance of ApigatewayService.
-
#list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse
Lists ApiConfigs in a given project and location.
-
#list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse
Lists Apis in a given project and location.
-
#list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse
Lists Gateways in a given project and location.
-
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse
Lists operations that match the specified filter in the request.
-
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse
Lists information about the supported locations for this service.
-
#patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Api.
-
#patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single ApiConfig.
-
#patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Gateway.
-
#set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource.
-
#test_project_location_api_config_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_project_location_api_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
-
#test_project_location_gateway_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource.
Constructor Details
#initialize ⇒ ApigatewayService
Returns a new instance of ApigatewayService.
47 48 49 50 51 52 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 47 def initialize super(DEFAULT_ENDPOINT_TEMPLATE, '', client_name: 'google-apis-apigateway_v1beta', client_version: Google::Apis::ApigatewayV1beta::GEM_VERSION) @batch_path = 'batch' end |
Instance Attribute Details
#key ⇒ String
Returns API key. Your API key identifies your project and provides you with API access, quota, and reports. Required unless you provide an OAuth 2.0 token.
40 41 42 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 40 def key @key end |
#quota_user ⇒ String
Returns Available to use for quota purposes for server-side applications. Can be any arbitrary string assigned to a user, but should not exceed 40 characters.
45 46 47 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 45 def quota_user @quota_user end |
Instance Method Details
#cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Starts asynchronous cancellation on a long-running operation. The server makes
a best effort to cancel the operation, but success is not guaranteed. If the
server doesn't support this method, it returns google.rpc.Code.UNIMPLEMENTED.
Clients can use Operations.GetOperation or other methods to check whether the
cancellation succeeded or whether the operation completed despite cancellation.
On successful cancellation, the operation is not deleted; instead, it becomes
an operation with an Operation.error value with a google.rpc.Status.code of 1
, corresponding to Code.CANCELLED.
1071 1072 1073 1074 1075 1076 1077 1078 1079 1080 1081 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1071 def cancel_project_location_operation(name, apigateway_cancel_operation_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+name}:cancel', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayCancelOperationRequest::Representation command.request_object = apigateway_cancel_operation_request_object command.response_representation = Google::Apis::ApigatewayV1beta::Empty::Representation command.response_class = Google::Apis::ApigatewayV1beta::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Api in a given project and location.
156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 156 def create_project_location_api(parent, apigateway_api_object = nil, api_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/apis', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApi::Representation command.request_object = apigateway_api_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['apiId'] = api_id unless api_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new ApiConfig in a given project and location.
458 459 460 461 462 463 464 465 466 467 468 469 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 458 def create_project_location_api_config(parent, apigateway_api_config_object = nil, api_config_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/configs', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig::Representation command.request_object = apigateway_api_config_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['apiConfigId'] = api_config_id unless api_config_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Creates a new Gateway in a given project and location.
766 767 768 769 770 771 772 773 774 775 776 777 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 766 def create_project_location_gateway(parent, apigateway_gateway_object = nil, gateway_id: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+parent}/gateways', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayGateway::Representation command.request_object = apigateway_gateway_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['parent'] = parent unless parent.nil? command.query['gatewayId'] = gateway_id unless gateway_id.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Api.
189 190 191 192 193 194 195 196 197 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 189 def delete_project_location_api(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single ApiConfig.
492 493 494 495 496 497 498 499 500 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 492 def delete_project_location_api_config(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Deletes a single Gateway.
799 800 801 802 803 804 805 806 807 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 799 def delete_project_location_gateway(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::Empty
Deletes a long-running operation. This method indicates that the client is no
longer interested in the operation result. It does not cancel the operation.
If the server doesn't support this method, it returns google.rpc.Code.
UNIMPLEMENTED.
1106 1107 1108 1109 1110 1111 1112 1113 1114 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1106 def delete_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:delete, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::Empty::Representation command.response_class = Google::Apis::ApigatewayV1beta::Empty command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayLocation
Gets information about a location.
74 75 76 77 78 79 80 81 82 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 74 def get_project_location(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayLocation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayLocation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApi
Gets details of a single Api.
219 220 221 222 223 224 225 226 227 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 219 def get_project_location_api(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayApi::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayApi command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayApiConfig
Gets details of a single ApiConfig.
526 527 528 529 530 531 532 533 534 535 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 526 def get_project_location_api_config(name, view: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig command.params['name'] = name unless name.nil? command.query['view'] = view unless view.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
571 572 573 574 575 576 577 578 579 580 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 571 def get_project_location_api_config_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
263 264 265 266 267 268 269 270 271 272 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 263 def get_project_location_api_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayGateway
Gets details of a single Gateway.
829 830 831 832 833 834 835 836 837 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 829 def get_project_location_gateway(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayGateway::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayGateway command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Gets the access control policy for a resource. Returns an empty policy if the resource exists and does not have a policy set.
873 874 875 876 877 878 879 880 881 882 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 873 def get_project_location_gateway_iam_policy(resource, options_requested_policy_version: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+resource}:getIamPolicy', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['options.requestedPolicyVersion'] = unless .nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#get_project_location_operation(name, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Gets the latest state of a long-running operation. Clients can use this method to poll the operation result at intervals as recommended by the API service.
1137 1138 1139 1140 1141 1142 1143 1144 1145 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1137 def get_project_location_operation(name, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse
Lists ApiConfigs in a given project and location.
611 612 613 614 615 616 617 618 619 620 621 622 623 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 611 def list_project_location_api_configs(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/configs', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListApiConfigsResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse
Lists Apis in a given project and location.
303 304 305 306 307 308 309 310 311 312 313 314 315 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 303 def list_project_location_apis(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/apis', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListApisResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse
Lists Gateways in a given project and location.
912 913 914 915 916 917 918 919 920 921 922 923 924 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 912 def list_project_location_gateways(parent, filter: nil, order_by: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+parent}/gateways', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListGatewaysResponse command.params['parent'] = parent unless parent.nil? command.query['filter'] = filter unless filter.nil? command.query['orderBy'] = order_by unless order_by.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse
Lists operations that match the specified filter in the request. If the server
doesn't support this method, it returns UNIMPLEMENTED.
1182 1183 1184 1185 1186 1187 1188 1189 1190 1191 1192 1193 1194 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1182 def list_project_location_operations(name, filter: nil, page_size: nil, page_token: nil, return_partial_success: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}/operations', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListOperationsResponse command.params['name'] = name unless name.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['returnPartialSuccess'] = return_partial_success unless return_partial_success.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse
Lists information about the supported locations for this service.
117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 117 def list_project_locations(name, extra_location_types: nil, filter: nil, page_size: nil, page_token: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:get, 'v1beta/{+name}/locations', ) command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayListLocationsResponse command.params['name'] = name unless name.nil? command.query['extraLocationTypes'] = extra_location_types unless extra_location_types.nil? command.query['filter'] = filter unless filter.nil? command.query['pageSize'] = page_size unless page_size.nil? command.query['pageToken'] = page_token unless page_token.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Api.
344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 344 def patch_project_location_api(name, apigateway_api_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApi::Representation command.request_object = apigateway_api_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single ApiConfig.
653 654 655 656 657 658 659 660 661 662 663 664 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 653 def patch_project_location_api_config(name, apigateway_api_config_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayApiConfig::Representation command.request_object = apigateway_api_config_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayOperation
Updates the parameters of a single Gateway.
954 955 956 957 958 959 960 961 962 963 964 965 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 954 def patch_project_location_gateway(name, apigateway_gateway_object = nil, update_mask: nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:patch, 'v1beta/{+name}', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayGateway::Representation command.request_object = apigateway_gateway_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayOperation::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayOperation command.params['name'] = name unless name.nil? command.query['updateMask'] = update_mask unless update_mask.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
691 692 693 694 695 696 697 698 699 700 701 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 691 def set_project_location_api_config_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
382 383 384 385 386 387 388 389 390 391 392 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 382 def set_project_location_api_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayPolicy
Sets the access control policy on the specified resource. Replaces any
existing policy. Can return NOT_FOUND, INVALID_ARGUMENT, and
PERMISSION_DENIED errors.
992 993 994 995 996 997 998 999 1000 1001 1002 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 992 def set_project_location_gateway_iam_policy(resource, apigateway_set_iam_policy_request_object = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:setIamPolicy', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewaySetIamPolicyRequest::Representation command.request_object = apigateway_set_iam_policy_request_object command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayPolicy::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayPolicy command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_api_config_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
730 731 732 733 734 735 736 737 738 739 740 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 730 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_api_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
421 422 423 424 425 426 427 428 429 430 431 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 421 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |
#test_project_location_gateway_iam_permissions(resource, apigateway_test_iam_permissions_request_object = nil, fields: nil, quota_user: nil, options: nil) {|result, err| ... } ⇒ Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse
Returns permissions that a caller has on the specified resource. If the
resource does not exist, this will return an empty set of permissions, not a
NOT_FOUND error. Note: This operation is designed to be used for building
permission-aware UIs and command-line tools, not for authorization checking.
This operation may "fail open" without warning.
1031 1032 1033 1034 1035 1036 1037 1038 1039 1040 1041 |
# File 'lib/google/apis/apigateway_v1beta/service.rb', line 1031 def (resource, = nil, fields: nil, quota_user: nil, options: nil, &block) command = make_simple_command(:post, 'v1beta/{+resource}:testIamPermissions', ) command.request_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsRequest::Representation command.request_object = command.response_representation = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse::Representation command.response_class = Google::Apis::ApigatewayV1beta::ApigatewayTestIamPermissionsResponse command.params['resource'] = resource unless resource.nil? command.query['fields'] = fields unless fields.nil? command.query['quotaUser'] = quota_user unless quota_user.nil? execute_or_queue_command(command, &block) end |